# encoding: utf-8
require 'fileutils'
require_relative '../generators/version'
require File.expand_path("./../../vendor/inflector", __FILE__)

module Storm
  STORM_DIR      = File.expand_path("#{File.dirname(__FILE__)}/../")
  STORM_ENV      = ENV['ENV'] || 'development'
  DB_VERSION     = ENV['DB_VERSION']   || nil
  DATABASE_DIR   = ENV['DATABASE_DIR'] || './db'
  APP_NAME       = ENV['APP_NAME']     || Inflector::classify(File.basename(FileUtils.pwd))
  MIGRATIONS_DIR = "#{DATABASE_DIR}/migrate"
  APP_DIR        = File.expand_path("./")

  def self.env
    @@env ||= STORM_ENV
  end

  def self.env=(value)
    @@env = value
  end

  def self.version
    Storm::Version.to_s
  end

  def self.app_name
    APP_NAME
  end

  def self.db_config
    ::YAML.load_file('./db/database.yml')[Storm.env.to_s]
  end

  def self.load_environment
    require 'active_record'
    require 'bundler'
    require 'awesome_print'
    ::Bundler.require(:default, :development)
    Dir["./package.rb"].each{|file| next if /db\// =~ file; require file }
    Dir["./*.rb"].sort.each{|file| next if /db\// =~ file; require file }
    Dir["./**/*.rb"].sort.each{|file| next if /db\// =~ file; require file }
  end

  def self.connect
    ActiveRecord::Base.establish_connection YAML.load_file('./db/database.yml')[Storm::STORM_ENV]
    begin
      require 'pry'
      Pry.color = true
      Pry.config.print = proc { |output, value| output.puts "=> #{value.ai}" }
    rescue Exception => e
      puts e
    end
  end
end
